#!/bin/bash

##
## This script allows users to specify the path to the 
## execution JRE.
##
## Author: Arthur Heffern
## Maintainer: Ryan Petersen
## Last Modified: July 5, 2017
##

DESTDIR=`dirname ${0}`

# If the user provided no path default to "/usr/java/latest"
checkPath () 
{	
	if [ x${JAVAINSTALLPATH} = "x" ]; then
		echo "No path provided, defaulting to /usr/java/latest"
        	JAVA_HOME="/usr/java/latest"
	else
        	JAVA_HOME=${JAVAINSTALLPATH}
	fi
}

# If no JAVA_HOME environment variable was found prompt the user for the path
if [ x${JAVA_HOME} = "x" ]; then
	echo "JAVA_HOME was not found, provide the path to your JRE (v1.8 or later): "
	read JAVAINSTALLPATH
	checkPath
else
	echo "Found JAVA_HOME at: " ${JAVA_HOME}...
	echo "Do you want to set this path [Y/N]?"
	read response
	
	if [ ${response} = "N" ] || [ ${response} = "n" ]; then
		echo "Enter the path to your JRE:"
		read JAVAINSTALLPATH	
		checkPath
	fi
fi

# Check if a JRE could be found at the given path
echo "Checking for Java Binary ${JAVA_HOME}/bin/java"
if [ ! -x ${JAVA_HOME}/bin/java ]; then
        echo "You do not appear to have the Sun Microsystems Java Runtime"
        echo "Environment (JRE) installed.  We could not find the java binary"
        echo "at:"
        echo ""
        echo "${JAVA_HOME}/bin/java"
        echo ""
        echo "This program will not function appropriately without"
        echo "Java 1.8 or greater."
        echo ""
        exit 1
fi

echo "Successfully found java runtime at: " ${JAVA_HOME}/bin/java

version=$(java -version 2>&1|awk -F\" '/version/ {print $2}' | awk -F '.' '{print $2}')
if [ ${version} -lt 8 ]; then
	echo "Warning, java version: " ${version} " found... 1.8 or greater is required."
fi

# Store the JRE path in config-vars.sh
echo "JAVA_HOME=${JAVA_HOME}" > ${DESTDIR}/config-vars.sh

